#ifndef	threadlib_h
#define	threadlib_h

/*
** Copyright 2000 Double Precision, Inc.  See COPYING for
** distribution information.
*/


#include	"config.h"

#ifdef __cplusplus
extern "C" {
#endif
#if 0
}
#endif

struct cthreadinfo;
struct cthreadlock;

#if	HAVE_PTHREADS
#include	"havepthread.h"
#else
#include	"nopthread.h"
#endif

#if 0
{
#endif
#ifdef __cplusplus
}
#endif
#endif
